<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuèlh',
	'article' => 'Article',
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Lu articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'Li a minga d’article à-n-aquela adreça ',
	'aucun_auteur' => 'Li a minga d’autor à-n-aquela adreça ',
	'aucun_site' => 'Li a minga de sit à-n-aquela adreça ',
	'aucune_breve' => 'Li a minga de brèva à-n-aquela adreça ',
	'aucune_rubrique' => 'Li a minga de rubrica à-n-aquela adreça ',
	'auteur' => 'Autor',
	'autres' => 'Autres',
	'autres_breves' => 'Autri brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mòts claus',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Boanjorn',

	// C
	'commenter_site' => 'Comentar aqueu sit',
	'contact' => 'Contacte',
	'copie_document_impossible' => 'Impossible de copiar lo document',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrièr ajust',
	'dernieres_breves' => 'Darrièras brèvas',
	'derniers_articles' => 'Darrièrs articles',
	'derniers_commentaires' => 'Darrièrs comentaris',
	'derniers_messages_forum' => 'Darrièrs messatges publicats dins lu fòros',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En respoasta à :',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// F
	'formats_acceptes' => 'Formats acceptats : @formats@.',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// L
	'lien_connecter' => 'Si conectar',

	// M
	'meme_auteur' => 'Dau meme autor',
	'meme_rubrique' => 'Dins la mema rubrica',
	'memes_auteurs' => 'Dei memes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges',
	'messages_recents' => 'Lu messatges de fòros mai recents',
	'mots_clef' => 'Mòt-clau',
	'mots_clefs' => 'Mòts claus',
	'mots_clefs_meme_groupe' => 'Mòts claus dins lo meme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Li novèutats',
	'nouveautes_web' => 'Novèutats sus lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas novèlas',

	// P
	'page_precedente' => 'pàgina anteriora',
	'page_suivante' => 'pàgina seguenta',
	'par_auteur' => 'da',
	'participer_site' => 'Podètz participar à la vida d’aqueu sit e prepauar lu voastres articles en vos inscrivent çai sota. Receberètz un e-mail que v’indicarà lu voastres còdes per accedir à l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepauar un site à ajustar dins aquela rubrica :',

	// R
	'repondre_article' => 'Respoandre à-n-aquel article',
	'repondre_breve' => 'Respoandre à-n-aquela brèva',
	'resultats_recherche' => 'Resultats de la recèrca',
	'retour_debut_forums' => 'Retorn au començament dei fòros',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realisat embé SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'spam' => 'Spam',
	'suite' => 'seguida',
	'sur_web' => 'Sus lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vequí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa li noveutas publicadi despí',

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vejatz en linha',
	'voir_squelette' => 'Veire l’esqueleta d’aquela pàgina'
);
