<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-ja',
	'0_langue' => '日本語 [ja]',
	'0_liste' => 'HU(hu_renraku@yahoo.co.jp), spip-ja@rezo.net',
	'0_mainteneur' => 'HU(hu_renraku@yahoo.co.jp), spip-dev@rezo.net',

	// A
	'access_interface_graphique' => '完全なグラフィカルインターフェースに戻る',
	'access_mode_texte' => 'シンプルなテキストインターフェースで表示',
	'admin_debug' => 'デバッグ',
	'admin_modifier_article' => 'この記事を修正',
	'admin_modifier_auteur' => 'この著者を修正',
	'admin_modifier_breve' => 'このニュースを修正',
	'admin_modifier_mot' => 'このキーワードを修正',
	'admin_modifier_rubrique' => 'このセクションを修正',
	'admin_recalculer' => 'ページの再読み込み',
	'afficher_trad' => '???????',
	'alerte_maj_impossible' => '<b>警告</b> My SQLは、データベースを@version@ にアップデート出来ませんでした。 データベースのアクセス権に問題があると思われます。インターネットサービスプロバイダにお問い合わせください。', # MODIF
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifié par ailleurs. La valeur actuelle est :', # MODIF
	'analyse_xml' => 'XML解析',
	'antispam_champ_vide' => '??????????????????',
	'articles_recents' => 'もっとも新しい記事',
	'avis_archive_incorrect' => 'その圧縮ファイルは、SPIP用ファイルではありません。',
	'avis_archive_invalide' => 'その圧縮ファイルは無効です。',
	'avis_attention' => '危ない！',
	'avis_champ_incorrect_type_objet' => 'タイプ @type@ のオブジェクトに対して、フィールド名 @name@ が無効です。',
	'avis_colonne_inexistante' => 'カラム @col@ が存在しません。',
	'avis_erreur' => 'エラー: 下記を参照',
	'avis_erreur_connexion' => '接続エラーです。',
	'avis_erreur_cookie' => 'クッキーの問題',
	'avis_erreur_fonction_contexte' => 'プログラミングエラーです。この機能はこの前後関係で呼び出されるべきではありません。', # MODIF
	'avis_erreur_mysql' => 'SQLのエラーです。', # MODIF
	'avis_erreur_sauvegarde' => 'バックアップエラーです　(@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'ƒvƒ‰ƒCƒx[ƒgƒXƒy[ƒXƒAƒNƒZƒX‚ÌÛ‚ÉƒGƒ‰[‚ª­¶‚µ‚Ü‚µ‚½',

	// B
	'barre_a_accent_grave' => 'アクセント記号つきの大文字Aを挿入してください。',
	'barre_aide' => 'よりよいページのレイアウトために、活字のショートカットを利用する。',
	'barre_e_accent_aigu' => '鋭いアクセントで大文字Eを挿入してください',
	'barre_eo' => 'OとEの合字の挿入(訳注:主にフランス語で使用)',
	'barre_eo_maj' => 'OとEの合字の大文字を挿入(訳注:主にフランス語で使用)',
	'barre_euro' => '「€」記号を入れてください。',
	'barre_gras' => '太字にする {{ボールド}}',
	'barre_guillemets' => '"２重引用符"の間の場所',
	'barre_guillemets_simples' => '’一重引用符’の間の場所',
	'barre_intertitre' => '変える {{{subheading}}}',
	'barre_italic' => '{イタリック} にする',
	'barre_lien' => 'ハイパーリンクの差込 [リンク先->http://...]',
	'barre_lien_input' => 'あなたのハイパーリンクの目標を入力してください (あなたはフォームのURLにhttp://mysite.com、あるいは単純にこのサイトの記事番号を与えてもよいです)。',
	'barre_note' => '変える [[Footnote]]',
	'barre_quote' => '<quote>メッセージへ引用符</quote>',
	'bouton_changer' => '修正する',
	'bouton_chercher' => '検索',
	'bouton_choisir' => '選択',
	'bouton_download' => 'ダウンロード', # MODIF
	'bouton_enregistrer' => '保存',
	'bouton_radio_desactiver_messagerie_interne' => '内部のメッセージ交換を停止',
	'bouton_radio_envoi_annonces' => '編集の発表を送る',
	'bouton_radio_non_envoi_annonces' => '発表を送らない',
	'bouton_radio_non_envoi_liste_nouveautes' => '最新ニュースリストを送らない',
	'bouton_recharger_page' => 'ページの再読み込み',
	'bouton_telecharger' => 'アップロード',
	'bouton_upload' => 'アップロード', # MODIF
	'bouton_valider' => '確定',

	// C
	'cal_apresmidi' => '午後 (p.m.)',
	'cal_jour_entier' => '全部の日',
	'cal_matin' => '午前 (a.m.)',
	'cal_par_jour' => '日めくりカレンダー',
	'cal_par_mois' => '月めくりカレンダー',
	'cal_par_semaine' => '週めくりカレンダー',
	'choix_couleur_interface' => '?',
	'choix_interface' => '??????????',
	'colonne' => '—',
	'confirm_changer_statut' => '承認を必要とします: あなたはこの記事のステータスの変更を要求しました。このまま続けてもいいですか？',
	'correcte' => '正しい',

	// D
	'date_aujourdhui' => '今日',
	'date_avant_jc' => 'B.C.',
	'date_dans' => 'in @delai@',
	'date_de_mois_1' => '@nommois@月@j@日',
	'date_de_mois_10' => '@nommois@月@j@日',
	'date_de_mois_11' => '@nommois@月@j@日',
	'date_de_mois_12' => '@nommois@月@j@日',
	'date_de_mois_2' => '@nommois@月@j@日',
	'date_de_mois_3' => '@nommois@月@j@日',
	'date_de_mois_4' => '@nommois@月@j@日',
	'date_de_mois_5' => '@nommois@月@j@日',
	'date_de_mois_6' => '@nommois@月@j@日',
	'date_de_mois_7' => '@nommois@月@j@日',
	'date_de_mois_8' => '@nommois@月@j@日',
	'date_de_mois_9' => '@nommois@月@j@日',
	'date_demain' => '明日',
	'date_fmt_heures_minutes' => '@h@時@m@分',
	'date_fmt_jour_heure' => '@jour@の@heure@',
	'date_fmt_jour_mois' => '@nommois@月@jour@日',
	'date_fmt_jour_mois_annee' => '@annee@年@nommois@月@jour@日',
	'date_fmt_mois_annee' => '@annee@年@nommois@月',
	'date_fmt_nomjour_date' => '@date@@nomjour@',
	'date_heures' => '時間',
	'date_hier' => '昨日',
	'date_il_y_a' => '@delai@前',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => '日曜日',
	'date_jour_1_abbr' => '日',
	'date_jour_1_initiale' => '日',
	'date_jour_2' => '月曜日',
	'date_jour_2_abbr' => '月',
	'date_jour_2_initiale' => '月',
	'date_jour_3' => '火曜日',
	'date_jour_3_abbr' => '火',
	'date_jour_3_initiale' => '火',
	'date_jour_4' => '水曜日',
	'date_jour_4_abbr' => '水',
	'date_jour_4_initiale' => '水',
	'date_jour_5' => '木曜日',
	'date_jour_5_abbr' => '木',
	'date_jour_5_initiale' => '木',
	'date_jour_6' => '金曜日',
	'date_jour_6_abbr' => '金',
	'date_jour_6_initiale' => '金',
	'date_jour_7' => '土曜日',
	'date_jour_7_abbr' => '土',
	'date_jour_7_initiale' => '土',
	'date_jours' => '日',
	'date_minutes' => '分',
	'date_mois' => 'ヶ月',
	'date_mois_1' => '1',
	'date_mois_10' => '10',
	'date_mois_11' => '11',
	'date_mois_12' => '12',
	'date_mois_2' => '2',
	'date_mois_3' => '3',
	'date_mois_4' => '4',
	'date_mois_5' => '5',
	'date_mois_6' => '6',
	'date_mois_7' => '7',
	'date_mois_8' => '8',
	'date_mois_9' => '9',
	'date_saison_1' => '冬',
	'date_saison_2' => '春',
	'date_saison_3' => '夏',
	'date_saison_4' => '秋',
	'date_secondes' => '秒',
	'date_semaines' => '週',
	'date_un_mois' => '月',
	'date_une_heure' => '時間',
	'date_une_minute' => '分',
	'date_une_semaine' => '週間',
	'dirs_commencer' => ' 本当にインストールを始めるために',
	'dirs_preliminaire' => '下準備: <b>アクセス権限を設定</b>',
	'dirs_probleme_droits' => '????????',
	'dirs_repertoires_absents' => '<b>次のディレクトリは見つかりませんでした: <ul>@bad_dirs@.</ul> </b>
  <p>考えられる原因は小文字大文字の扱い方が間違っている
  これらのディレクトリの小文字大文字が上に表示されているものと一致しているかどうか確認してください
  そし彼らがそうしないときは、エラーを修正するためにあなたのFTPクライアントを使って、ディレクトリをリネームして下さい。
  </p><p>これらが終われば、出来るでしょう</p>', # MODIF
	'dirs_repertoires_suivants' => '<b>次のディレクトリに書き込む許可がありません: <ul>@bad_dirs@.</ul> </b>

  <p>これを変えるために、あなたのFTPクライアントを使い、これらのディレクトリにアクセス許可を設定してください

  手順はインストールガイドに記述してあります

  </p><p>この操作を完了できれば、出来ることでしょう </p>', # MODIF
	'double_occurrence' => 'Double occurrence', # MODIF

	// E
	'envoi_via_le_site' => 'サイト経由で送信',
	'erreur' => 'ƒGƒ‰[',

	// F
	'fichier_introuvable' => '見つからなかったファイル: @fichier@',
	'form_deja_inscrit' => 'あなたは既に登録されています。',
	'form_email_non_valide' => 'あなたのe-mailアドレスは有効ではありません。',
	'form_forum_access_refuse' => 'あなたはもう、このサイトへアクセスすることができません。',
	'form_forum_bonjour' => '素晴らしい日を @nom@、',
	'form_forum_email_deja_enregistre' => 'このe-mailアドレスは登録済みです、従って、あなたはいつものパスワードを使うことが出来ます。',
	'form_forum_identifiant_mail' => 'あなたの新しいIDは、ちょうど今、e-mailであなたに送られたところです。',
	'form_forum_identifiants' => '個人ID',
	'form_forum_indiquer_nom_email' => 'あなたの名前とe-mailアドレスをここに入力して下さい。まもなくe-mailによって、IDを受け取ることでしょう。',
	'form_forum_login' => 'ログインID:',
	'form_forum_message_auto' => '(これは自動送信されたメッセージです)',
	'form_forum_pass' => 'パスワード:',
	'form_forum_probleme_mail' => 'メール送信中の障害: IDを送ることが、出来ませんでした。',
	'form_forum_voici1' => 'ここにサイトでの生活に参加するための、あなたのIDがあります
"@nom_site_spip@" (@adresse_site@):', # MODIF
	'form_forum_voici2' => '記事を提出するためのあなたのIDです。
サイト "@nom_site_spip@" (@adresse_login@):', # MODIF
	'form_indiquer_email' => 'あなたのe-mailアドレスを入力して下さい。',
	'form_indiquer_nom' => 'あなたの名前を入力して下さい。',
	'form_indiquer_nom_site' => 'あなたのサイトの名前を入力して下さい。',
	'form_pet_deja_enregistre' => 'このサイトは既に登録済みです',
	'form_pet_signature_pasprise' => 'あなたの署名は無視されました。',
	'form_prop_confirmer_envoi' => '発送を確認',
	'form_prop_description' => '種類/コメント',
	'form_prop_enregistre' => 'あなたの提案は記録されました、管理者によって適正検査された後オンラインに現れるでしょう。',
	'form_prop_envoyer' => 'メッセージを送る',
	'form_prop_indiquer_email' => 'どうか有効なe-mailアドレスを入力して下さい',
	'form_prop_indiquer_nom_site' => 'サイトの名前を入力して下さい。',
	'form_prop_indiquer_sujet' => '題名を入力して下さい',
	'form_prop_message_envoye' => '送られたメッセージ',
	'form_prop_non_enregistre' => 'あなたの提案は記録されませんでした。',
	'form_prop_sujet' => '題名',
	'form_prop_url_site' => 'サイトのURL', # MODIF
	'forum_non_inscrit' => 'あなたが未登録なのか、アドレスかパスワードが間違っているのかどちらかです。',
	'forum_par_auteur' => 'by @auteur@',
	'forum_titre_erreur' => 'エラー...',

	// I
	'ical_texte_rss_articles' => 'サイトの記事のbackendファイルのアドレスは:',
	'ical_texte_rss_articles2' => 'また、あなたはサイトのそれぞれのセクションの記事のためのbackendファイルを取得することが出来る:',
	'ical_texte_rss_breves' => 'さらに、サイトのニュース記事を含んでいるファイルがあります。セクション番号を選択することによって、あなたはそのセクションのニュースだけ取得できました。',
	'icone_a_suivre' => 'パッドを起動',
	'icone_admin_site' => 'サイトの管理',
	'icone_agenda' => '日記',
	'icone_aide_ligne' => 'ヘルプ',
	'icone_articles' => '記事',
	'icone_auteurs' => '著者たち',
	'icone_brouteur' => '素早いブラウジング',
	'icone_configuration_site' => '設定',
	'icone_configurer_site' => 'あなたのサイトの設定',
	'icone_creer_nouvel_auteur' => '新しい著者を作る',
	'icone_creer_rubrique' => 'セクションを作る',
	'icone_creer_sous_rubrique' => 'サブセクションを作る',
	'icone_deconnecter' => '切断',
	'icone_discussions' => '議論',
	'icone_doc_rubrique' => '添付しているドキュメント',
	'icone_ecrire_article' => '新しい記事を書く',
	'icone_edition_site' => 'サイトの編集',
	'icone_gestion_langues' => '言語管理',
	'icone_informations_personnelles' => '個人情報',
	'icone_interface_complet' => '完全なインターフェース',
	'icone_interface_simple' => 'シンプルなインターフェース',
	'icone_maintenance_site' => 'サイトメンテナンス',
	'icone_messagerie_personnelle' => '個人的なメッセージ交換',
	'icone_repartition_debut' => '初めからのディストリビューションを表示',
	'icone_rubriques' => 'セクション',
	'icone_sauver_site' => 'サイトのバックアップ',
	'icone_site_entier' => 'サイトの全体',
	'icone_sites_references' => '参照されたサイト',
	'icone_statistiques' => 'サイトの統計',
	'icone_suivi_activite' => 'サイトの活動の手助け',
	'icone_suivi_actualite' => 'サイトの統計',
	'icone_suivi_pettions' => '署名の把握、管理',
	'icone_suivi_revisions' => '記事修正',
	'icone_supprimer_document' => 'このドキュメントを削除',
	'icone_supprimer_image' => 'この画像を削除',
	'icone_tous_articles' => 'あなたのすべての記事',
	'icone_tous_auteur' => 'すべての著者たち',
	'icone_visiter_site' => 'サイトを訪れる', # MODIF
	'icone_voir_en_ligne' => 'オンラインで見る',
	'img_indisponible' => '利用できないイメージ',
	'impossible' => '不可能',
	'info_a_suivre' => 'PADを起動»',
	'info_acces_interdit' => 'アクセスが許されなかった',
	'info_acces_refuse' => 'アクセスが拒否された',
	'info_action' => 'アクション: @action@',
	'info_administrer_rubriques' => 'あなたはこのセクションとサブセクションを管理することができます',
	'info_adresse_non_indiquee' => 'あなたはテストをするためのアドレスを指定しませんでした!',
	'info_aide' => 'ヘルプ：',
	'info_ajouter_mot' => 'このキーワードを追加する',
	'info_annonce' => 'アナウンス',
	'info_annonces_generales' => '一般アナウンス:',
	'info_article_propose' => '提出済みの記事',
	'info_article_publie' => '掲げれた記事',
	'info_article_redaction' => '進行中の記事',
	'info_article_refuse' => '断れた記事',
	'info_article_supprime' => '消した記事',
	'info_articles' => '記事',
	'info_articles_a_valider' => '検査済み記事',
	'info_articles_proposes' => '提出された記事',
	'info_auteurs_nombre' => '著者(たち):',
	'info_authentification_ftp' => '認証 (FTPによって)。',
	'info_breves_2' => 'ニュース',
	'info_connexion_refusee' => '接続が拒否された',
	'info_contact_developpeur' => '開発者に連絡を取って下さい。',
	'info_contenance' => 'このサイトのコンテンツ:',
	'info_contribution' => '掲示板の投稿', # MODIF
	'info_copyright' => '@spip@ は、@lien_gpl@ で配布されているフリーソフトです。',
	'info_copyright_doc' => '更なる情報を得るには、<a href="@spipnet@">http://www.spip.net/ja</a>を見てください。', # MODIF
	'info_copyright_gpl' => 'GPLライセンスのもと',
	'info_cours_edition' => '進行中のあなたの記事', # MODIF
	'info_creer_repertoire' => '呼び出されたファイルかディレクトリを作って下さい:',
	'info_creer_repertoire_2' => 'サブディレクトリ <b>@repertoire@</b>内、それから', # MODIF
	'info_creer_vignette' => '自動的に作成されたサムネイル',
	'info_deplier' => '示す',
	'info_descriptif_nombre' => '記述:',
	'info_description' => '記述:',
	'info_description_2' => '記述:',
	'info_dimension' => 'サイズ:',
	'info_ecire_message_prive' => 'プライベートなメッセージを書く',
	'info_email_invalide' => '無効なe-mailアドレス。',
	'info_en_cours_validation' => '進行中のあなたの記事',
	'info_en_ligne' => '今オンライン:',
	'info_envoyer_message_prive' => 'この著者にプライベートメッセージを送る',
	'info_erreur_requete' => '照会でのエラー:',
	'info_erreur_squelette2' => 'テンプレートが入手不可能 <b>@fichier@</b>...',
	'info_erreur_systeme' => 'システムエラー (エラー番号 @errsys@)',
	'info_erreur_systeme2' => 'ハードディスクがいっぱいか、データベースがダメージを受けている。<br />
<span style="color:red;">試してみて <a href=\'@script@\'>データベースの修復</a>,
 それかあなたのホストに問い合わせてください。</span>', # MODIF
	'info_fini' => '終わった！',
	'info_format_image' => 'ビネット(半身写真、模様等)の作成に使える画像のフォーマット: @gd_formats@。',
	'info_format_non_defini' => '未定義のフォーマット',
	'info_grand_ecran' => '大きく表示',
	'info_image_aide' => 'ヘルプ',
	'info_image_process_titre' => 'サムネイルの作り方',
	'info_impossible_lire_page' => '<b>エラー!</b> ページを読むことが出来なかった <tt><html>@test_proxy@</html></tt> プロキシを介して <tt>', # MODIF
	'info_installation_systeme_publication' => '出版システムインストレーション ...',
	'info_installer_documents' => 'あなたは@upload@フォルダにあるすべてのドキュメントを自動的にインストール出来ます。', # MODIF
	'info_installer_ftp' => '管理者なら@upload@フォルダに（FTPで）ファイルを置いておけば、後でここから直接そのファイルを選択できるようになります。', # MODIF
	'info_installer_images' => 'あなたはJPEG、GIF、PNGフォーマットの画像をインストール出来ます。',
	'info_installer_images_dossier' => '@upload@ フォルダにインストールしたファイルをここで選択することが出来ます。', # MODIF
	'info_interface_complete' => '完全なインターフェース',
	'info_interface_simple' => 'シンプルなインターフェース',
	'info_joindre_document_article' => 'あなたはあなたの記事へタイプのドキュメントを付着させることが出来ます。',
	'info_joindre_document_rubrique' => 'あなたはこのセクションにタイプのドキュメントを追加できます。',
	'info_joindre_documents_article' => 'あなたはあなたの記事へタイプの記事を付着することが出来ます:',
	'info_l_article' => '記事',
	'info_la_breve' => 'そのニュース',
	'info_la_rubrique' => 'そのセクション',
	'info_langue_principale' => 'サイトの主な言語',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ ピクセル',
	'info_les_auteurs_1' => ' @les_auteurs@によって',
	'info_logo_format_interdit' => '@formats@フォーマットのロゴのみ許可します。',
	'info_logo_max_poids' => 'ロゴは、@maxi@より少ないべきです（このファイルは@actuel@）。',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'メッセージ',
	'info_message_supprime' => 'メッセージは削除された',
	'info_mise_en_ligne' => 'オンラインに公表された日付:',
	'info_modification_parametres_securite' => 'セキュリティパラメータの変更',
	'info_mois_courant' => 'その月:',
	'info_mot_cle_ajoute' => '次のキーワードが追加された to',
	'info_multi_herit' => 'デフォルト言語',
	'info_multi_langues_soulignees' => '<u>下線が引かれている言語</u> インターフェースのすべての文章が翻訳されています。あなたがその言語を選んだとき、パブリックなサイトの多くの要素（日付、形式）は自動的に翻訳されるでしょう。下線が引かれていない言語は、それらの要素はサイトのメイン言語の時にだけ現れるでしょう。', # MODIF
	'info_multilinguisme' => '多言語',
	'info_nom_non_utilisateurs_connectes' => 'あなたの名前は接続しているユーザーのリストに現れない。',
	'info_nom_utilisateurs_connectes' => 'あなたの名前は接続しているユーザーのリストに現れる。',
	'info_nombre_en_ligne' => '今オンライン:',
	'info_non_resultat' => '"@cherche_mot@" に対する結果は無い',
	'info_non_utilisation_messagerie' => 'あなたはこのサイトの内部のメッセージ交換を使用していない。',
	'info_nouveau_message' => 'あなたに１通メッセージが届いています',
	'info_nouveaux_messages' => 'あなたに@total_messages@通のメッセージが来ています',
	'info_numero_abbreviation' => 'No',
	'info_pense_bete' => 'メモ',
	'info_petit_ecran' => '小さく表示',
	'info_pixels' => 'ピクセル',
	'info_plusieurs_mots_trouves' => '"@cherche_mot@"についていくつかのキーワードが見つかった:',
	'info_portfolio_automatique' => '自動作成の代表作品集:',
	'info_premier_resultat' => '[@debut_limit@ 初めの結果、トータル @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ 最初の結果、トータル @total@]',
	'info_propose_1' => '[@nom_site_spip@] 提出されました: @titre@',
	'info_propose_2' => '提出された記事
-------------',
	'info_propose_3' => '記事 "@titre@" は公開するために提出されました。',
	'info_propose_4' => 'あなたに記事をよく調べて、意見を述べることを求めています。',
	'info_propose_5' => 'その記事に関連した掲示板でお願いします。次のURLでその掲示板に移動できます:',
	'info_publie_01' => '記事 "@titre@" @connect_nom@によって適正検査がなされました。',
	'info_publie_1' => '[@nom_site_spip@] 公表されました: @titre@',
	'info_publie_2' => '公表された記事
-----------------',
	'info_rechercher' => 'サイト内検索',
	'info_rechercher_02' => '検索 :',
	'info_remplacer_vignette' => 'カスタマイズしたロゴによってデフォルトのビネット(半身像、写真)を置き換える:',
	'info_sans_titre_2' => '無名',
	'info_selectionner_fichier' => 'あなたは@upload@フォルダのファイルを選択することが出来ます。', # MODIF
	'info_selectionner_fichier_2' => '選択したファイル:',
	'info_supprimer_vignette' => 'ビネット(半身像、模様)を削除',
	'info_symbole_bleu' => '<b>青</b>のシンボルは、<b>メモ</b>を表します: すなわちあなたが個人的に使用するメッセージ', # MODIF
	'info_symbole_jaune' => '<b>黄色</b>のシンボルは、<b>すべてのエディターへのアナウンス</b>: それはすべての管理者が編集でき、すべてのエディターに見えます。', # MODIF
	'info_symbole_vert' => '<b>緑</b>のシンボルは、サイトの<b>他のユーザーと交換したメッセージ</b>。', # MODIF
	'info_telecharger_nouveau_logo' => '新しいロゴをアップロード:',
	'info_telecharger_ordinateur' => 'あなたのコンピュータからアップロード:',
	'info_tous_resultats_enregistres' => '[すべての結果は記録されます]',
	'info_tout_afficher' => 'すべてを表示',
	'info_travaux_texte' => 'このサイトはまだ準備中です。また後で来てください...',
	'info_travaux_titre' => '建設中のサイト',
	'info_trop_resultat' => '"@cherche_mot@"に対する結果が多すぎます; キーワードを絞って検索して下さい。',
	'info_utilisation_messagerie_interne' => 'あなたはこのサイトの内部のメッセージ交換を使っています。',
	'info_valider_lien' => 'このリンクの適正検査',
	'info_verifier_image' => '、あなたの画像が適切に転送されたか確認して下さい。',
	'info_vignette_defaut' => '標準の写真、模様',
	'info_vignette_personnalisee' => 'ビネット(半身写真、模様など)をカスタマイズ',
	'info_visite' => '１つの訪問:',
	'info_vos_rendez_vous' => 'あなたの次の約束',
	'infos_vos_pense_bete' => 'あなたのメモ', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'アイコン表示のみ',
	'lien_afficher_texte_icones' => 'アイコンとテキストの表示',
	'lien_afficher_texte_seul' => 'テキスト表示のみ',
	'lien_liberer' => 'リリース',
	'lien_liberer_tous' => 'それらの記事は無料です', # MODIF
	'lien_nouvea_pense_bete' => '新しいメモ',
	'lien_nouveau_message' => '新しいメッセージ',
	'lien_nouvelle_annonce' => '新しいアナウンス',
	'lien_petitions' => '署名機能',
	'lien_popularite' => '人気度: @popularite@%',
	'lien_racine_site' => 'サイトのルート',
	'lien_reessayer' => 'もう一度トライ',
	'lien_repondre_message' => 'このメッセージに返信する',
	'lien_supprimer' => '削除',
	'lien_tout_afficher' => 'すべて表示',
	'lien_visite_site' => 'このサイトを訪問',
	'lien_visites' => '@visites@訪問',
	'lien_voir_auteur' => 'この著者を調べる',
	'ligne' => '—ñ',
	'login_acces_prive' => 'プライベートエリアへアクセスする',
	'login_autre_identifiant' => '他のIDで接続する',
	'login_cookie_accepte' => 'クッキーを許可するようにあなたのブラウザを設定してください（少なくともこのサイトの）。',
	'login_cookie_oblige' => '確実にあなた自身を確認するために、あなたはクッキーを許可しなければなりません。',
	'login_deconnexion_ok' => '切断された。',
	'login_erreur_pass' => 'パスワードエラー。',
	'login_espace_prive' => 'プライベートエリア',
	'login_identifiant_inconnu' => 'そのID、"@login@"は、知りません。',
	'login_login' => 'ログインID:',
	'login_login2' => 'ログインID（このサイトに接続するためのID）:', # MODIF
	'login_login_pass_incorrect' => '（ログインIDかパスワードが間違っています）。',
	'login_motpasseoublie' => 'パスワードを忘れましたか？',
	'login_non_securise' => '警告：このフォームは安全でないです。
   もしあなたがパスワードを
   ネットワーク上で傍受されたくないのなら、あなたのブラウザの
   javascriptを有効にして',
	'login_nouvelle_tentative' => '新しい試み',
	'login_par_ici' => 'あなたは登録済みです... このように...',
	'login_pass2' => 'パスワード:',
	'login_preferez_refuser' => '<b>もしあなたがクッキーを拒絶する方がいいなら</b>、他の接続方法(それほど安全でない)をあなたが自由に使うことが出来る:',
	'login_recharger' => 'このページを再読込してください<br />',
	'login_rester_identifie' => '数日の間ログオンしたままにする',
	'login_retour_public' => 'パブリックなサイトへ戻る',
	'login_retour_site' => 'パブリックなサイトへ戻る',
	'login_retoursitepublic' => 'パブリックなサイトへ戻る',
	'login_sinscrire' => '登録',
	'login_test_navigateur' => 'ブラウザが再接続を試みている',
	'login_verifiez_navigateur' => '(しかし、あなたのブラウザがあなたのパスワードを記憶しなかったかどうか確かめて下さい...)',

	// M
	'module_fichiers_langues' => '言語ファイル',

	// N
	'navigateur_pas_redirige' => 'もし、あなたのブラウザがリダイレクトしないなら、続けるためにここをクリックして下さい。',

	// O
	'onglet_affacer_base' => 'データベースの削除',
	'onglet_auteur' => '著者',
	'onglet_contenu_site' => 'そのサイトのコンテンツ',
	'onglet_evolution_visite_mod' => '訪問度合い',
	'onglet_fonctions_avances' => '進行した機能',
	'onglet_informations_personnelles' => '個人情報',
	'onglet_interactivite' => '対話性',
	'onglet_messagerie' => 'メッセージ交換',
	'onglet_repartition_rubrique' => 'セクションによるディストリビューション',
	'onglet_save_restaur_base' => 'バックアップ/復元 データベース',
	'onglet_vider_cache' => '空のキャッシュ',

	// P
	'pass_choix_pass' => 'あなたの新しいパスワードを決めてください:',
	'pass_erreur' => 'エラー',
	'pass_erreur_acces_refuse' => '<b>エラー:</b> あなたはもう、このサイトへのアクセスを持っていません。',
	'pass_erreur_code_inconnu' => '<b>エラー:</b> このコードはサイトへのアクセス許可を持ったどの訪問者とも一致しません。',
	'pass_erreur_non_enregistre' => '<b>エラー:</b> アドレス <tt>@email_oubli@</tt> はこのサイトに登録されていません。',
	'pass_erreur_non_valide' => '<b>エラー:</b> そのアドレス<tt>@email_oubli@</tt> は有効ではありません！',
	'pass_erreur_probleme_technique' => '<b>エラー:</b> このe-mailは、技術的な問題によって送ることができませんでした。',
	'pass_espace_prive_bla' => 'このサイトのプライベートエリアは、登録後訪問者に開かれます。あなたが登録したなら、
あなたは進行中の記事を観覧したり、
記事を提出したり、すべての掲示板に参加できます。',
	'pass_forum_bla' => 'あなたは登録者専用の掲示板に参加したいと
リクエストしました。',
	'pass_indiquez_cidessous' => 'あなたが前に登録したe-mailアドレスを
下に入力してください。
あなたのアクセスが再び出来るよう、どのようにすればよいかをe-mailで受信するでしょう。',
	'pass_mail_passcookie' => '(これは自動メッセージです)

サイト
@nom_site_spip@ (@adresse_site@)
へあなたのアクセスを取り戻す為には
次のアドレスに行ってください:
    @sendcookie@

あなたはそれから新しいパスワードを入力して
サイトへまた接続することができます。
', # MODIF
	'pass_mot_oublie' => 'パスワードを忘れた',
	'pass_nouveau_enregistre' => 'あなたの新しいパスワードを記録しました。',
	'pass_nouveau_pass' => '新しいパスワード',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'パスワードを忘れている',
	'pass_quitter_fenetre' => 'このウィンドウを終了する',
	'pass_rappel_login' => 'リマインダー: あなたのID (ログインID) は " @login@ "。',
	'pass_recevoir_mail' => 'あなたは、このサイトへどのようにアクセスできるかの説明を、e-mailで受け取るでしょう。',
	'pass_retour_public' => 'パブリックなサイトへ戻る',
	'pass_rien_a_faire_ici' => 'ここでする事は無い。',
	'pass_vousinscrire' => 'サイトに登録します',
	'precedent' => '前',
	'previsualisation' => 'プレビュー',
	'previsualiser' => 'プレビューを表示する',

	// S
	'squelette' => 'テンプレート',
	'squelette_inclus_ligne' => 'template, lineを含んでいます',
	'squelette_ligne' => 'template, line',
	'stats_visites_et_popularite' => '@visites@訪問; 人気度: @popularite@',
	'suivant' => '次へ',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'あなたがインターフェースに精通したとき、クリック «',
	'texte_actualite_site_2' => '完全なインターフェース',
	'texte_actualite_site_3' => '» さらに多くの特徴を利用可能にするように。',
	'texte_creation_automatique_vignette' => 'このサイトで使用可能なビネットのプレビューの自動作成。あなたがインストールするとき、このフォームを通して、@gd_formats@フォーマットの画像、最大サイズが@taille_preview@ピクセルのビネットと結びつけられるでしょう。',
	'texte_documents_associes' => '次のドキュメントは、記事で、関連づけられます、
    しかしそれらはダイレクトに
    挿入されない。パブリックなサイトのレイアウトをベースにして、
    それらは付加されたドキュメントとして現れることができました。',
	'texte_erreur_mise_niveau_base' => 'アップグレード中のデータベースエラー。
      画像 <b>@fichier@</b> をパスすることが出来なかった (記事 @id_article@)。<p>
      慎重にこの参照に注意します、
      また最後にまだ記事に画像が現れることを
      確認して下さい。', # MODIF
	'texte_inc_auth_1' => 'あなたはあなた自身をログインID
  <b>@auth_login@</b>と思っていますが、それはデータベースに存在しません(もう)。
  Try to', # MODIF
	'texte_inc_auth_2' => '再接続',
	'texte_inc_auth_3' => '終了しました
  もし必要ならばあなたのブラウザを再起動してください。',
	'texte_inc_config' => '下で入力した変更はサイトの機能に躊躇に
  影響を与えます。あなたがSPIPシステムの機能に精通していないなら
 それらを扱わないように助言します<br /><br /><b>より
 一般的に、あなたは
 あなたのサイトの主なウェブマスターにこのページを取り扱わせることを強くお勧めします。</b>', # MODIF
	'texte_inc_meta_1' => 'ファイル <code>@fichier@</code>に書き込もうとしたとき、システムはエラーに遭遇しました。サイトの管理者としてお願いします。', # MODIF
	'texte_inc_meta_2' => '書き込み許可の確認',
	'texte_inc_meta_3' => '<code>@repertoire@</code>ディレクトリの。', # MODIF
	'texte_statut_en_cours_redaction' => '編集進行中',
	'texte_statut_poubelle' => 'ゴミ箱の中',
	'texte_statut_propose_evaluation' => '評価のため提出中',
	'texte_statut_publie' => 'オンラインに公開中',
	'texte_statut_refuse' => '拒否された',
	'titre_ajouter_mot_cle' => 'キーワードの追加:',
	'titre_cadre_raccourcis' => 'ショートカット:',
	'titre_changer_couleur_interface' => 'インターフェースの色を変える',
	'titre_image_admin_article' => 'あなたはこの記事を管理することができます',
	'titre_image_administrateur' => '管理者',
	'titre_image_aide' => 'このアイテムについてのヘルプ',
	'titre_image_auteur_supprime' => '削除された著者',
	'titre_image_redacteur' => 'アクセス無しのエディタ',
	'titre_image_redacteur_02' => '編集者',
	'titre_image_visiteur' => '訪問者',
	'titre_joindre_document' => 'ドキュメントを置く',
	'titre_mots_cles' => 'キーワード',
	'titre_probleme_technique' => '警告: 技術的な問題 (SQL server) サイトのこの部分へのアクセスを防ぎます。<p>あなたの理解に感謝します。', # MODIF
	'titre_publier_document' => 'このセクションで文章を公開する',
	'titre_statistiques' => 'サイトの統計',
	'titre_titre_document' => '文章のタイトル:',
	'trad_reference' => '(参考記事)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': Bタグはループ内で遅すぎる',
	'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n’existe pas', # MODIF
	'zbug_boucle' => 'ループ',
	'zbug_boucle_recursive_undef' => '未定義な回帰的なループ', # MODIF
	'zbug_champ_hors_boucle' => 'ループ外の @champ@ フィールド',
	'zbug_champ_hors_motif' => 'ループ外の @champ@ フィールドは @motif@ とタグされた', # MODIF
	'zbug_code' => 'コード',
	'zbug_critere_inconnu' => '未知の基準 @critere@', # MODIF
	'zbug_distant_interdit' => '外部のデータが禁じられます', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
	'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
	'zbug_erreur_boucle_double' => '歪んでいる@id@: ２重登録', # MODIF
	'zbug_erreur_boucle_fermant' => '歪んでいる@id@: 欠けている終了タグ', # MODIF
	'zbug_erreur_boucle_syntaxe' => '間違ったループ (歪んだ) 構文 ', # MODIF
	'zbug_erreur_execution_page' => 'ページの計算でエラー', # MODIF
	'zbug_erreur_filtre' => 'エラー - 未定義のフィルター: <b>"@filtre@"</b>', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} only applies to loops (FORUMS) and (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'テンプレート内でエラー',
	'zbug_info_erreur_squelette' => 'サイトのエラー',
	'zbug_inversion_ordre_inexistant' => '実在しない命令の逆転', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION sans critère {pagination} ou employé dans une boucle recursive', # MODIF
	'zbug_parametres_inclus_incorrects' => 'インクルードのパラメタが間違っている', # MODIF
	'zbug_resultat' => '結果',
	'zbug_serveur_indefini' => '未定義のSQL server', # MODIF
	'zbug_table_inconnue' => 'SQLテーブル "@table@" は見つからない'
);
