<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'ホーム', # MODIF
	'articles' => '記事',
	'articles_auteur' => 'この記事の著者',
	'articles_populaires' => '最も読まれている記事',
	'articles_rubrique' => 'このセクションの記事',
	'aucun_article' => 'このアドレスに記事はありません',
	'aucun_auteur' => 'このアドレスに著者はいません',
	'aucun_site' => 'このアドレスにサイトはありません',
	'aucune_breve' => 'このアドレスにニュースはありません',
	'aucune_rubrique' => 'このアドレスにセクションはありません',
	'autres_breves' => '他のニュース',
	'autres_groupes_mots_clefs' => 'キーワードの他のグループ',
	'autres_sites' => '他のサイト',

	// B
	'bonjour' => 'おはようございます',

	// C
	'commenter_site' => 'このサイトについてコメントして下さい',

	// D
	'date' => '日付',
	'dernier_ajout' => '最新の追加',
	'dernieres_breves' => '最新のニュース',
	'derniers_articles' => '最新の記事',
	'derniers_commentaires' => '最新のコメント',
	'derniers_messages_forum' => 'フォーラムで投稿された最新のメッセージ',

	// E
	'edition_mode_texte' => 'テキストモードonly',
	'en_reponse' => 'Replying to:',
	'en_resume' => 'まとめ',
	'envoyer_message' => 'メッセージを送る',
	'espace_prive' => 'プライベートエリア',

	// H
	'hierarchie_site' => 'サイトの階層',

	// J
	'jours' => '日付け',

	// M
	'meme_auteur' => '同じ著者によって',
	'meme_rubrique' => '同じセクションの中で',
	'memes_auteurs' => '同じ著者によって',
	'message' => 'メッセージ',
	'messages_forum' => 'フォーラムメッセージ', # MODIF
	'messages_recents' => '最も新しいフォーラムのメッセージ',
	'mots_clefs' => 'キーワード',
	'mots_clefs_meme_groupe' => '同じグループのキーワード',

	// N
	'navigation' => 'ナビゲーション',
	'nom' => '名前',
	'nouveautes' => '新しいもの',
	'nouveautes_web' => 'Webの中で新しいもの',
	'nouveaux_articles' => '新しい記事',
	'nouvelles_breves' => '新しいニュース',

	// P
	'page_precedente' => '前のページ',
	'page_suivante' => '次のページ',
	'par_auteur' => 'によって ',
	'participer_site' => 'あなたはこのウェブサイトで活動することによって、登録後、あなたの記事を書くことが出来ます。それからあなたはすぐに、サイトのプライベートエリアへのアクセスコードを、emailによって得られるでしょう。',
	'plan_site' => 'サイトマップ',
	'popularite' => 'ポピュラー',
	'poster_message' => 'メッセージを投稿',
	'proposer_site' => 'あなたはこのセクションに追加するサイトを提案することが出来ます:',

	// R
	'repondre_article' => 'この記事に返信',
	'repondre_breve' => 'このニュースに返信',
	'resultats_recherche' => '検索結果',
	'retour_debut_forums' => 'フォーラムの最初のページに戻る',
	'rubrique' => 'セクション',
	'rubriques' => 'セクション',

	// S
	'signatures_petition' => '署名',
	'site_realise_avec_spip' => 'SPIPによってサイトは作られました',
	'sites_web' => 'ウェブサイト',
	'sous_rubriques' => 'サブセクション',
	'suite' => '次の',
	'sur_web' => 'ウェブ上',
	'syndiquer_rubrique' => 'このセクションを供給する',
	'syndiquer_site' => 'サイト全体を供給する',

	// T
	'texte_lettre_information' => 'サイトのニュースレターはここ',
	'texte_lettre_information_2' => 'この手紙は、以来公表された記事とニュースをまとめてあります。', # MODIF

	// V
	'ver_imprimer' => 'バージョン表記',
	'voir_en_ligne' => 'オンラインを見る',
	'voir_squelette' => '???????????????' # MODIF
);
